Crate board_game_traits

Crate board_game_traits 

Traits for abstract game position representations.

General game-agnostic tools and engines can be built on this module Represents any 2-player sequential, deterministic, perfect-information game. This includes many popular games such as chess, go, xiangqi, othello, connect four and tic-tac-toe.

Enums

Color
Represents a player’s color.
GameResult
The result of a game after it has finished.

Traits

EvalPosition
A game position that also includes a heuristic static evaluation function. Enables the use of many game-playing algorithms, such as minimax.
ExtendedPosition
An extended game representation, which includes many additional methods to help game-playing algorithms search more effectively.
Position
The simplest abstract representation of a game position. Together, the provided methods encode all the rules of the game.